@@ -1,4 +1,3 @@
-from quaterion.dataset.cache_data_loader import CacheDataLoader
 from quaterion.dataset.similarity_data_loader import (
     GroupSimilarityDataLoader,
     PairsSimilarityDataLoader,
@@ -8,3 +7,4 @@ from quaterion.dataset.similarity_samples import (
     SimilarityGroupSample,
     SimilarityPairSample,
 )
+from quaterion.dataset.similarity_dataset import SimilarityGroupDataset
