@@ -1,5 +1,6 @@
 from torch import Tensor, LongTensor
 
+from quaterion.distances import Distance
 from quaterion.loss.similarity_loss import SimilarityLoss
 
 
@@ -7,13 +8,10 @@ class GroupLoss(SimilarityLoss):
     """Base class for Group losses.
 
     Args:
-        distance_metric_name: Name of the function, that returns a distance between two embeddings.
-            :class:`~quaterion.loss.metrics.SiameseDistanceMetric` contains pre-defined metrics
-            that can be used.
-
+        distance_metric_name: Name of the distance function, e.g., :class:`~quaterion.distances.Distance`.
     """
 
-    def __init__(self, distance_metric_name: str = "cosine_distance"):
+    def __init__(self, distance_metric_name: Distance = Distance.COSINE):
         super(GroupLoss, self).__init__(distance_metric_name=distance_metric_name)
 
     def forward(self, embeddings: Tensor, groups: LongTensor) -> Tensor:
