@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Collection, Hashable, Any, List, Callable, Union, Tuple, Iterable
+from typing import Hashable, Any, List, Callable, Union, Tuple
 
 from torch import Tensor
 
@@ -8,7 +8,9 @@ from quaterion_models.types import TensorInterchange, CollateFnType
 
 KeyExtractorType = Callable[[Any], Hashable]
 
-CacheCollateReturnType = Union[List[Hashable], Tuple[Hashable, TensorInterchange]]
+CacheCollateReturnType = Union[
+    List[Hashable], Tuple[List[Hashable], "TensorInterchange"]
+]
 
 
 class CacheMode(str, Enum):
@@ -24,6 +26,8 @@ class CacheEncoder(Encoder):
 
     Args:
         encoder: Encoder object to be wrapped.
+
+    :meta private:
     """
 
     def __init__(self, encoder: Encoder):
@@ -55,7 +59,7 @@ class CacheEncoder(Encoder):
 
     def cache_collate(
         self, batch: Union[Tuple[List[Hashable], List[Any]], List[Hashable]]
-    ) -> Union[List[Hashable], Tuple[List[Hashable], TensorInterchange]]:
+    ) -> "CacheCollateReturnType":
         """Converts raw data batch into suitable model input and keys for caching.
 
         Returns:
@@ -73,7 +77,7 @@ class CacheEncoder(Encoder):
             # Only keys are provided here
             return batch
 
-    def get_collate_fn(self) -> CollateFnType:
+    def get_collate_fn(self) -> "CollateFnType":
         """Provides function that converts raw data batch into suitable model input.
 
         Returns:
@@ -81,7 +85,7 @@ class CacheEncoder(Encoder):
         """
         return self.cache_collate
 
-    def forward(self, batch: TensorInterchange) -> Tensor:
+    def forward(self, batch: "TensorInterchange") -> Tensor:
         """Infer encoder.
 
         Convert input batch to embeddings
@@ -93,7 +97,7 @@ class CacheEncoder(Encoder):
         """
         raise NotImplementedError()
 
-    def save(self, output_path: str):
+    def save(self, output_path: str) -> None:
         """Persist current state to the provided directory
 
         Args:
@@ -111,7 +115,7 @@ class CacheEncoder(Encoder):
         """
         raise ValueError("Cached encoder does not support loading")
 
-    def fill_cache(self, keys: List[Hashable], data: TensorInterchange) -> None:
+    def fill_cache(self, keys: List[Hashable], data: "TensorInterchange") -> None:
         """Apply wrapped encoder to data and store processed data on
         corresponding device.
 
